function J = farfield(Mesh,U,point,k,R_in,R_out)

QuadRule = P3O2();

 % Initialize constants
  
  nElements = size(Mesh.Elements,1);
  nGauss = size(QuadRule.w,1);
  
  % Precompute gradients of shape functions
  
  grad_N = grad_shap_LFE(QuadRule.x);
  N = shap_LFE(QuadRule.x);
  
  J = 0;
  for ii = 1:nElements
     
    % Extract vertices of current element
    
    idx = Mesh.Elements(ii,:);
    Vertices = Mesh.Coordinates(idx,:);
    
    % Compute element mapping
    
    bK = Vertices(1,:);
    BK = [Vertices(2,:)-bK; Vertices(3,:)-bK];
    inv_BK_t = transpose(inv(BK));
    det_BK = abs(det(BK));
    
    x = QuadRule.x*BK+ones(nGauss,1)*bK;
 
    % Compute function values on current element
    
    u = U(idx(1))*N(:,1)+U(idx(2))*N(:,2)+U(idx(3))*N(:,3);
    grad_Psi = PsiHandle(x,Mesh.ElemFlag(ii),R_in,R_out); 
    grad_u = (U(idx(1))*grad_N(:,1:2)+U(idx(2))*grad_N(:,3:4) + ...
              U(idx(3))*grad_N(:,5:6))*inv_BK_t;
    wave = exp(-1i*k*(point(1)*x(:,1)+point(2)*x(:,2)));
    grad_wave(:,1) = -1i*k*point(1)*wave;
    grad_wave(:,2) = -1i*k*point(2)*wave;
    
    % Update flux 
    
    J = J +exp(1i*pi/4)/sqrt(8*pi*k)*sum(QuadRule.w.*(sum(grad_wave.*grad_Psi,2).*u+...
        -sum(grad_u.*grad_Psi,2).*wave))*det_BK;
      
  end

return